@@ -369,7 +369,7 @@ It is registered to variable `mime-preview-quitting-method-alist'."
 	  (save-window-excursion
 	    (set-buffer full-buf)
 	    (erase-buffer)
-	    (binary-insert-file-contents file)
+	    (binary-insert-encoded-file file)
 	    (setq major-mode 'mime-show-message-mode)
 	    (mime-view-buffer (current-buffer) nil mother)
 	    (setq pbuf (current-buffer))
@@ -420,24 +420,21 @@ It is registered to variable `mime-preview-quitting-method-alist'."
 		    (or (file-exists-p file)
 			(throw 'tag nil)
 			)
-		    (binary-insert-file-contents file)
+		    (binary-insert-encoded-file file)
 		    (goto-char (point-max))
-		    (setq i (1+ i))
-		    ))
-		(binary-write-region (point-min)(point-max)
-				     (expand-file-name "FULL" root-dir))
+		    (setq i (1+ i))))
+		(binary-write-decoded-region
+		 (point-min)(point-max)
+		 (expand-file-name "FULL" root-dir))
 		(let ((i 1))
 		  (while (<= i total)
 		    (let ((file (format "%s/%d" root-dir i)))
 		      (and (file-exists-p file)
-			   (delete-file file)
-			   ))
-		    (setq i (1+ i))
-		    ))
+			   (delete-file file)))
+		    (setq i (1+ i))))
 		(let ((file (expand-file-name "CT" root-dir)))
 		  (and (file-exists-p file)
-		       (delete-file file)
-		       ))
+		       (delete-file file)))
 		(let ((buf (current-buffer))
 		      (pwin (or (get-buffer-window mother)
 				(get-largest-window)))
